@@ -1,9 +1,10 @@
-from ninja import Router, Schema
+from ninja import Router
 from unidecode import unidecode
 from typing import List
 from django.shortcuts import get_object_or_404
 
 from django.db.models import Max
+from django.db.models import Q
 
 from francedata.models import (
     Metadata,
@@ -13,9 +14,18 @@ from francedata.models import (
     Commune,
     DataYear,
 )
+from francedata.models.collectivity import (
+    CommuneData,
+    DepartementData,
+    EpciData,
+    RegionData,
+)
 
 from francedata.schemas import (
-    DataYearSchema,
+    CommuneDataSchema,
+    DepartementDataSchema,
+    EpciDataSchema,
+    RegionDataSchema,
     RegionSchema,
     DepartementSchema,
     EpciSchema,
@@ -83,47 +93,62 @@ def search_subdivisions(request, query: str, category: str = None, year: int = N
         epcis_year_entry = regions_year_entry
         communes_year_entry = regions_year_entry
 
-    if len(query) < 3 and (category == "communes" or return_all_categories):
-        shortnamed_communes = [
-            "by",
-            "bu",
-            "eu",
-            "gy",
-            "oz",
-            "oo",
-            "py",
-            "ri",
-            "ry",
-            "sy",
-            "ur",
-            "us",
-            "uz",
-            "y",
-        ]
-        if query in shortnamed_communes:
-            communes_raw = Commune.objects.filter(
-                name__unaccent__iexact=query, years__exact=communes_year_entry
-            )
+    if len(query) < 3:
+        if category == "communes" or return_all_categories:
+            shortnamed_communes = [
+                "by",
+                "bu",
+                "eu",
+                "gy",
+                "oz",
+                "oo",
+                "py",
+                "ri",
+                "ry",
+                "sy",
+                "ur",
+                "us",
+                "uz",
+                "y",
+            ]
+            if query in shortnamed_communes:
+                communes_raw = Commune.objects.filter(
+                    name__unaccent__iexact=query, years__exact=communes_year_entry
+                )
+        if query.isnumeric() and (category == "departements" or return_all_categories):
+            departements_raw = Departement.objects.filter(insee=query)
+        if query.isnumeric() and (category == "regions" or return_all_categories):
+            regions_raw = Region.objects.filter(insee=query)
     else:
         if category == "regions" or return_all_categories:
             regions_raw = Region.objects.filter(
-                name__unaccent__istartswith=query, years__exact=regions_year_entry
+                Q(name__unaccent__istartswith=query)
+                | Q(siren__startswith=query)
+                | Q(insee__startswith=query),
+                years__exact=regions_year_entry,
             ).exclude(
                 siren__exact=""
             )  # Exclude Mayotte that has no region-level Siren
         if category == "departements" or return_all_categories:
             departements_raw = Departement.objects.filter(
-                name__unaccent__istartswith=query, years__exact=departements_year_entry
+                Q(name__unaccent__istartswith=query)
+                | Q(siren__startswith=query)
+                | Q(insee__startswith=query),
+                years__exact=departements_year_entry,
             ).exclude(
                 siren__exact=""
             )  # Exclude Haute-Corse, Corse-du-Sud, Martinique and Guyane that have no departement-level Siren
         if category == "epcis" or return_all_categories:
             epcis_raw = Epci.objects.filter(
-                name__unaccent__icontains=query, years__exact=epcis_year_entry
+                Q(name__unaccent__icontains=query) | Q(siren__startswith=query),
+                years__exact=epcis_year_entry,
             )
         if category == "communes" or return_all_categories:
             communes_raw = Commune.objects.filter(
-                name__unaccent__istartswith=query, years__exact=communes_year_entry
+                Q(name__unaccent__istartswith=query)
+                | Q(siren__startswith=query)
+                | Q(insee__startswith=query),
+                years__exact=communes_year_entry,
             )
 
     if len(regions_raw):
@@ -273,3 +298,141 @@ def get_commune_by_siren(request, siren_id):
 def get_commune_by_insee(request, insee_id):
     item = get_object_or_404(Commune, insee=insee_id)
     return item
+
+
+# Region data
+@router.get("/regiondata/{siren_id}", response=List[RegionDataSchema], tags=["data"])
+def get_region_data(request, siren_id):
+    """
+    Return all data for the given region
+    """
+    queryset = RegionData.objects.filter(region__siren=siren_id)
+    return queryset
+
+
+@router.get(
+    "/regiondata/{siren_id}/latest", response=List[RegionDataSchema], tags=["data"]
+)
+def get_latest_region_data(request, siren_id):
+    """
+    Return the latest data for the given region
+    """
+    max_year = RegionData.objects.latest("year__year").year
+    queryset = RegionData.objects.filter(region__siren=siren_id, year=max_year)
+    return queryset
+
+
+@router.get(
+    "/regiondata/{siren_id}/{year}", response=List[RegionDataSchema], tags=["data"]
+)
+def get_region_data_by_year(request, siren_id, year):
+    """
+    Return data for the given region and the given year
+    """
+    queryset = RegionData.objects.filter(region__siren=siren_id, year__year=year)
+    return queryset
+
+
+# Departement data
+@router.get(
+    "/departementdata/{siren_id}", response=List[DepartementDataSchema], tags=["data"]
+)
+def get_departement_data(request, siren_id):
+    """
+    Return all data for the given département
+    """
+    queryset = DepartementData.objects.filter(departement__siren=siren_id)
+    return queryset
+
+
+@router.get(
+    "/departementdata/{siren_id}/latest",
+    response=List[DepartementDataSchema],
+    tags=["data"],
+)
+def get_latest_departement_data(request, siren_id):
+    """
+    Return the latest data for the given département
+    """
+    max_year = DepartementData.objects.latest("year__year").year
+    queryset = DepartementData.objects.filter(
+        departement__siren=siren_id, year=max_year
+    )
+    return queryset
+
+
+@router.get(
+    "/departementdata/{siren_id}/{year}",
+    response=List[DepartementDataSchema],
+    tags=["data"],
+)
+def get_departement_data_by_year(request, siren_id, year):
+    """
+    Return data for the given département and the given year
+    """
+    queryset = DepartementData.objects.filter(
+        departement__siren=siren_id, year__year=year
+    )
+    return queryset
+
+
+# EPCI data
+@router.get("/epcidata/{siren_id}", response=List[EpciDataSchema], tags=["data"])
+def get_epci_data(request, siren_id):
+    """
+    Return all data for the given EPCI
+    """
+    queryset = EpciData.objects.filter(epci__siren=siren_id)
+    return queryset
+
+
+@router.get("/epcidata/{siren_id}/latest", response=List[EpciDataSchema], tags=["data"])
+def get_latest_epci_data(request, siren_id):
+    """
+    Return latest data for the given EPCI
+    """
+    max_year = EpciData.objects.latest("year__year").year
+    queryset = EpciData.objects.filter(epci__siren=siren_id, year=max_year)
+    return queryset
+
+
+@router.get("/epcidata/{siren_id}/{year}", response=List[EpciDataSchema], tags=["data"])
+def get_epci_data_by_year(request, siren_id, year):
+    """
+    Return data for the given EPCI and the given year
+    """
+    queryset = EpciData.objects.filter(epci__siren=siren_id, year__year=year)
+    return queryset
+
+
+# Commune
+@router.get("/communedata/{siren_id}", response=List[CommuneDataSchema], tags=["data"])
+def get_commune_data(request, siren_id):
+    """
+    Return all data for the given commune
+    """
+    queryset = CommuneData.objects.filter(commune__siren=siren_id)
+    return queryset
+
+
+@router.get(
+    "/communedata/{siren_id}/latest", response=List[CommuneDataSchema], tags=["data"]
+)
+def get_latest_commune_data(request, siren_id):
+    """
+    Return the latest data for the given commune
+    """
+    max_year = CommuneData.objects.latest("year__year").year
+    queryset = CommuneData.objects.filter(commune__siren=siren_id, year=max_year)
+    return queryset
+
+
+@router.get(
+    "/communedata/{siren_id}/{year}", response=List[CommuneDataSchema], tags=["data"]
+)
+def get_commune_data_by_year(request, siren_id, year):
+    """
+    Return data for the given commune and the given year
+    """
+    queryset = CommuneData.objects.filter(commune__siren=siren_id, year__year=year)
+    return queryset
